==> texlive-bin_2017.20170613.44572.orig.tar.xz: texlive-bin-2017.20170613.44572/texk/dvisvgm/dvisvgm-src/src/SpecialManager.hpp <==
/*************************************************************************
** SpecialManager.hpp                                                   **
**                                                                      **
** This file is part of dvisvgm -- a fast DVI to SVG converter          **
** Copyright (C) 2005-2017 Martin Gieseking <martin.gieseking@uos.de>   **
**                                                                      **
** This program is free software; you can redistribute it and/or        **
** modify it under the terms of the GNU General Public License as       **
** published by the Free Software Foundation; either version 3 of       **
** the License, or (at your option) any later version.                  **
**                                                                      **
** This program is distributed in the hope that it will be useful, but  **
** WITHOUT ANY WARRANTY; without even the implied warranty of           **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         **
** GNU General Public License for more details.                         **
**                                                                      **
** You should have received a copy of the GNU General Public License    **
** along with this program; if not, see <http://www.gnu.org/licenses/>. **
*************************************************************************/

#ifndef SPECIALMANAGER_HPP
#define SPECIALMANAGER_HPP

#include <map>
#include <ostream>
#include <string>
#include <vector>
#include "SpecialHandler.hpp"

class SpecialActions;

class SpecialManager
{
	private:
		typedef std::vector<SpecialHandler*> HandlerPool;
		typedef std::map<std::string,SpecialHandler*> HandlerMap;

	public:
		~SpecialManager ();
		static SpecialManager& instance ();
		void registerHandler (SpecialHandler *handler);
		void registerHandlers (SpecialHandler **handlers, const char *ignorelist);
		void unregisterHandlers ();
		void preprocess (const std::string &special, SpecialActions &actions) const;
		bool process (const std::string &special, double dvi2bp, SpecialActions &actions) const;
		void notifyPreprocessingFinished () const;
		void notifyBeginPage (unsigned pageno, SpecialActions &actions) const;
		void notifyEndPage (unsigned pageno, SpecialActions &actions) const;
		void notifyPositionChange (double x, double y, SpecialActions &actions) const;
		void writeHandlerInfo (std::ostream &os) const;

	protected:
		SpecialManager () {}
		SpecialManager (const SpecialManager &) {}
		SpecialHandler* findHandler (const std::string &prefix) const;

	private:
		HandlerPool _pool;     ///< stores pointers to all handlers
		HandlerMap _handlers;  ///< pointers to handlers for corresponding prefixes
		std::vector<DVIPreprocessingListener*> _preprocListeners;
		std::vector<DVIBeginPageListener*> _beginPageListeners;
		std::vector<DVIEndPageListener*> _endPageListeners;
		std::vector<DVIPositionListener*> _positionListeners;
};

#endif

==> texlive-bin_2018.20180824.48463.orig.tar.xz: texlive-bin-2018.20180824.48463/texk/dvisvgm/dvisvgm-src/src/SpecialManager.hpp <==
/*************************************************************************
** SpecialManager.hpp                                                   **
**                                                                      **
** This file is part of dvisvgm -- a fast DVI to SVG converter          **
** Copyright (C) 2005-2018 Martin Gieseking <martin.gieseking@uos.de>   **
**                                                                      **
** This program is free software; you can redistribute it and/or        **
** modify it under the terms of the GNU General Public License as       **
** published by the Free Software Foundation; either version 3 of       **
** the License, or (at your option) any later version.                  **
**                                                                      **
** This program is distributed in the hope that it will be useful, but  **
** WITHOUT ANY WARRANTY; without even the implied warranty of           **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         **
** GNU General Public License for more details.                         **
**                                                                      **
** You should have received a copy of the GNU General Public License    **
** along with this program; if not, see <http://www.gnu.org/licenses/>. **
*************************************************************************/

#ifndef SPECIALMANAGER_HPP
#define SPECIALMANAGER_HPP

#include <memory>
#include <ostream>
#include <string>
#include <unordered_map>
#include <vector>
#include "SpecialHandler.hpp"

class SpecialActions;

class SpecialManager {
	private:
		using HandlerPool = std::vector<std::unique_ptr<SpecialHandler>>;
		using HandlerMap = std::unordered_map<std::string,SpecialHandler*>;

	public:
		static SpecialManager& instance ();
		void registerHandler (std::unique_ptr<SpecialHandler> &&handler);
		void registerHandlers (std::vector<std::unique_ptr<SpecialHandler>> &handlers, const char *ignorelist);
		void unregisterHandlers ();
		void preprocess (const std::string &special, SpecialActions &actions) const;
		bool process (const std::string &special, double dvi2bp, SpecialActions &actions) const;
		void notifyPreprocessingFinished () const;
		void notifyBeginPage (unsigned pageno, SpecialActions &actions) const;
		void notifyEndPage (unsigned pageno, SpecialActions &actions) const;
		void notifyPositionChange (double x, double y, SpecialActions &actions) const;
		void writeHandlerInfo (std::ostream &os) const;
		SpecialHandler* findHandlerByName (const std::string &name) const;

	protected:
		SpecialManager () =default;
		SpecialManager (const SpecialManager &) =delete;
		SpecialHandler* findHandlerByPrefix (const std::string &prefix) const;

	private:
		HandlerPool _handlerPool;      ///< stores pointers to all handlers
		HandlerMap _handlersByPrefix;  ///< pointers to handlers for corresponding prefixes
};

#endif
